==> de-unkrig-commons-1.1.1-sources.jar: de/unkrig/commons/lang/protocol/ConsumerWhichThrows.java <==

/*
 * de.unkrig.commons - A general-purpose Java class library
 *
 * Copyright (c) 2011, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.commons.lang.protocol;

/**
 * Like {@link Consumer}, but the {@link #consume(Object)} method is permitted to throw a given exception.
 * <p>
 * <h3>IMPORTANT NOTICE:</h3>
 * When using this type in a variable, parameter or field declaration, <b>never</b> write
 * <pre>ConsumerWhichThrows&lt;<i>consumed-type</i>, <i>thrown-exception</i>></pre>
 * , but always
 * <pre>ConsumerWhichThrows&lt;? super <i>consumed-type</i>, ? extends <i>thrown-exception</i>></pre>
 * .
 *
 * @param <T>  The type of the consumed subjects
 * @param <EX> The throwable type that {@link #consume(Object)} may throw
 */
public
interface ConsumerWhichThrows<T, EX extends Throwable> {

    /**
     * Consumes one {@code subject} of type {@code T}.
     * <p>
     * Generally subjects should either be immutable, or the 'ownership' of the product should pass from the caller
     * to the consumer. Particularly, the consumer should not be called with one (mutable) instance more than once.
     */
    void
    consume(T subject) throws EX;
}

==> de-unkrig-commons-1.1.6-sources.jar: de/unkrig/commons/lang/protocol/ConsumerWhichThrows.java <==

/*
 * de.unkrig.commons - A general-purpose Java class library
 *
 * Copyright (c) 2011, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.commons.lang.protocol;

/**
 * Like {@link Consumer}, but the {@link #consume(Object)} method is permitted to throw a given exception.
 *
 * <h3>IMPORTANT NOTICE:</h3>
 * <p>When using this type in a variable, parameter or field declaration, <b>never</b> write:</p>
 * <pre>ConsumerWhichThrows&lt;<i>consumed-type</i>, <i>thrown-exception</i>></pre>
 * <p>, but always:</p>
 * <pre>ConsumerWhichThrows&lt;? super <i>consumed-type</i>, ? extends <i>thrown-exception</i>></pre>
 *
 * @param <T>  The type of the consumed subjects
 * @param <EX> The throwable type that {@link #consume(Object)} may throw
 */
public
interface ConsumerWhichThrows<T, EX extends Throwable> {

    /**
     * Consumes one {@code subject} of type {@code T}.
     * <p>
     *   Generally subjects should either be immutable, or the 'ownership' of the product should pass from the caller
     *   to the consumer. Particularly, the consumer should not be called with one (mutable) instance more than once.
     * </p>
     */
    void
    consume(T subject) throws EX;
}
